# Generic QEMU guest agent in Python.
#
# Author: Peter Odding <peter@peterodding.com>
# Last Change: September 24, 2014
# URL: https://negotiator.readthedocs.org

"""
``negotiator_common.utils`` - Miscellaneous functions
=====================================================
"""


def compact(text, **kw):
    """
    Compact whitespace and format any arguments into the given string.

    Trims leading and trailing whitespace, replaces runs of whitespace with a
    single space and formats any keyword arguments into the resulting string
    using :py:func:`str.format()`.

    :param text: The text to compact (a string).
    :param kw: Any keyword arguments to apply using :py:func:`str.format()`.
    :returns: The compacted, formatted string.
    """
    return ' '.join(text.split()).format(**kw)


def format_call(function, *args, **kw):
    """
    Format a Python function call into a human readable string.

    :param function: The name of the function that's called (a string).
    :param args: The positional arguments to the function (if any).
    :param kw: The keyword arguments to the function (if any).
    """
    formatted_arguments = []
    for argument in args:
        formatted_arguments.append(repr(argument))
    for keyword, value in kw.items():
        formatted_arguments.append("%s=%r" % (keyword, value))
    return "%s(%s)" % (function, ', '.join(formatted_arguments))



#!/usr/bin/python

# Setup script for the `negotiator-common' package.
#
# Author: Peter Odding <peter@peterodding.com>
# Last Change: September 24, 2014
# URL: https://negotiator.readthedocs.org

"""Setup script for the ``negotiator-common`` package."""

# Standard library modules.
import os
import re

# De-facto standard solution for Python packaging.
from setuptools import setup, find_packages

# Find the directory where the source distribution was unpacked.
source_directory = os.path.dirname(os.path.abspath(__file__))

# Find the current version.
module = os.path.join(source_directory, 'negotiator_common', '__init__.py')
for line in open(module, 'r'):
    match = re.match(r'^__version__\s*=\s*["\']([^"\']+)["\']$', line)
    if match:
        version_string = match.group(1)
        break
else:
    raise Exception("Failed to extract version from %s!" % module)

# Fill in the long description (for the benefit of PyPI)
# with the contents of README.rst (rendered by GitHub).
try:
    readme_file = os.path.join(source_directory, 'README.rst')
    readme_text = open(readme_file, 'r').read()
except IOError:
    # This happens on readthedocs.org.
    readme_text = ''

setup(name='negotiator-common',
      version=version_string,
      description="Generic QEMU guest agent (common functionality)",
      long_description=readme_text,
      url='https://negotiator.readthedocs.org',
      author="Peter Odding",
      author_email='peter@peterodding.com',
      packages=find_packages(),
      include_package_data=True,
      install_requires=[
          'executor >= 1.3',
      ])



# Generic QEMU guest agent in Python.
#
# Author: Peter Odding <peter@peterodding.com>
# Last Change: September 24, 2014
# URL: https://negotiator.readthedocs.org

"""
``negotiator_common.config`` - Configuration defaults
=====================================================

.. data:: CHANNELS_DIRECTORY

   The pathname of the directory containing the host side of each channel.
   Defaults to ``/var/lib/libvirt/qemu/channel/target``.

.. data:: USER_COMMANDS_DIRECTORY

   The pathname of the directory containing user defined commands that 'the
   other side' can invoke through Negotiator. Defaults to
   ``/usr/lib/negotiator/commands``.

.. data:: GUEST_TO_HOST_CHANNEL_NAME

   The name of the channel that's used for communication initiated by the
   guest. Defaults to ``negotiator-guest-to-host.0``.

.. data:: HOST_TO_GUEST_CHANNEL_NAME

   The name of the channel that's used for communication initiated by the
   host. Defaults to ``negotiator-host-to-guest.0``.
"""

import os

CHANNELS_DIRECTORY = '/var/lib/libvirt/qemu/channel/target'
USER_COMMANDS_DIRECTORY = '/usr/lib/negotiator/commands'
BUILTIN_COMMANDS_DIRECTORY = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'scripts')
GUEST_TO_HOST_CHANNEL_NAME = 'negotiator-guest-to-host.0'
HOST_TO_GUEST_CHANNEL_NAME = 'negotiator-host-to-guest.0'
